package br.com.stoneage.identify.identify_sdk_flutter.codecs

import br.com.stoneage.identify.identify_sdk_flutter.errors.IdentifyError
import br.com.stoneage.identify.identify_sdk_flutter.models.AndroidOnlyDeviceInformation
import br.com.stoneage.identify.identify_sdk_flutter.models.DeviceInformationResult
import br.com.stoneage.identify.identify_sdk_flutter.models.LocationData
import io.flutter.plugin.common.StandardMessageCodec
import java.io.ByteArrayOutputStream
import java.nio.ByteBuffer

object IdentifySdkPluginDeviceInformationCodec : StandardMessageCodec() {
    override fun readValueOfType(type: Byte, buffer: ByteBuffer): Any? {
        return when (type) {
            128.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    AndroidOnlyDeviceInformation.fromList(it)
                }
            }

            129.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    DeviceInformationResult.fromList(it)
                }
            }

            130.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    IdentifyError.fromList(it)
                }
            }
            //NOTE: As the name suggests, these are only iOS information
            /*131.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    IosOnlyDeviceInformation.fromList(it)
                }
            }*/

            132.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    LocationData.fromList(it)
                }
            }

            else -> super.readValueOfType(type, buffer)
        }
    }

    override fun writeValue(stream: ByteArrayOutputStream, value: Any?) {
        when (value) {
            is AndroidOnlyDeviceInformation -> {
                stream.write(128)
                writeValue(stream, value.toList())
            }

            is DeviceInformationResult -> {
                stream.write(129)
                writeValue(stream, value.toList())
            }

            is IdentifyError -> {
                stream.write(130)
                writeValue(stream, value.toList())
            }
            //NOTE: As the name suggests, these are only iOS information
            /*is IosOnlyDeviceInformation -> {
                stream.write(131)
                writeValue(stream, value.toList())
            }*/

            is LocationData -> {
                stream.write(132)
                writeValue(stream, value.toList())
            }

            else -> super.writeValue(stream, value)
        }
    }
}