package br.com.stoneage.identify.identify_sdk_flutter.codecs

import br.com.stoneage.identify.identify_sdk_flutter.errors.IdentifyError
import br.com.stoneage.identify.identify_sdk_flutter.models.CollectOcrResult
import br.com.stoneage.identify.identify_sdk_flutter.models.OcrInfo
import io.flutter.plugin.common.StandardMessageCodec
import java.io.ByteArrayOutputStream
import java.nio.ByteBuffer

object IdentifySdkPluginOcrCodec : StandardMessageCodec() {
    override fun readValueOfType(type: Byte, buffer: ByteBuffer): Any? {
        return when (type) {
            128.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    CollectOcrResult.fromList(it)
                }
            }

            129.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    IdentifyError.fromList(it)
                }
            }

            130.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    OcrInfo.fromList(it)
                }
            }
            
            else -> super.readValueOfType(type, buffer)
        }
    }

    override fun writeValue(stream: ByteArrayOutputStream, value: Any?) {
        when (value) {
            is CollectOcrResult -> {
                stream.write(128)
                writeValue(stream, value.toList())
            }

            is IdentifyError -> {
                stream.write(129)
                writeValue(stream, value.toList())
            }

            is OcrInfo -> {
                stream.write(130)
                writeValue(stream, value.toList())
            }

            else -> super.writeValue(stream, value)
        }
    }
}
