package br.com.stoneage.identify.identify_sdk_flutter.codecs

import br.com.stoneage.identify.identify_sdk_flutter.errors.CollectSelfieError
import br.com.stoneage.identify.identify_sdk_flutter.errors.IdentifyError
import br.com.stoneage.identify.identify_sdk_flutter.models.AgeRange
import br.com.stoneage.identify.identify_sdk_flutter.models.BiometricResult
import br.com.stoneage.identify.identify_sdk_flutter.models.CollectSelfieParameters
import br.com.stoneage.identify.identify_sdk_flutter.models.CollectSelfieResult
import br.com.stoneage.identify.identify_sdk_flutter.models.LivenessResult
import br.com.stoneage.identify.identify_sdk_flutter.models.SelfieInfo
import br.com.stoneage.identify.identify_sdk_flutter.models.SelfieOptionalValidations
import io.flutter.plugin.common.StandardMessageCodec
import java.io.ByteArrayOutputStream
import java.nio.ByteBuffer

object IdentifySdkPluginSelfieCodec : StandardMessageCodec() {
    override fun readValueOfType(type: Byte, buffer: ByteBuffer): Any? {
        return when (type) {
            128.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    AgeRange.fromList(it)
                }
            }

            129.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    BiometricResult.fromList(it)
                }
            }

            130.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    CollectSelfieError.fromList(it)
                }
            }

            131.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    CollectSelfieParameters.fromList(it)
                }
            }

            132.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    CollectSelfieResult.fromList(it)
                }
            }

            133.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    IdentifyError.fromList(it)
                }
            }

            134.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    LivenessResult.fromList(it)
                }
            }

            135.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    SelfieInfo.fromList(it)
                }
            }

            136.toByte() -> {
                return (readValue(buffer) as? List<Any?>)?.let {
                    SelfieOptionalValidations.fromList(it)
                }
            }

            else -> super.readValueOfType(type, buffer)
        }
    }

    override fun writeValue(stream: ByteArrayOutputStream, value: Any?) {
        when (value) {
            is AgeRange -> {
                stream.write(128)
                writeValue(stream, value.toList())
            }

            is BiometricResult -> {
                stream.write(129)
                writeValue(stream, value.toList())
            }

            is CollectSelfieError -> {
                stream.write(130)
                writeValue(stream, value.toList())
            }

            is CollectSelfieParameters -> {
                stream.write(131)
                writeValue(stream, value.toList())
            }

            is CollectSelfieResult -> {
                stream.write(132)
                writeValue(stream, value.toList())
            }

            is IdentifyError -> {
                stream.write(133)
                writeValue(stream, value.toList())
            }

            is LivenessResult -> {
                stream.write(134)
                writeValue(stream, value.toList())
            }

            is SelfieInfo -> {
                stream.write(135)
                writeValue(stream, value.toList())
            }

            is SelfieOptionalValidations -> {
                stream.write(136)
                writeValue(stream, value.toList())
            }

            else -> super.writeValue(stream, value)
        }
    }
}