package br.com.stoneage.identify.identify_sdk_flutter.enums

import br.com.stoneage.identify.enums.ErrorStatusEnum as NativeEnum

enum class IdentifyErrorCodeEnum(val raw: Int) {
    CANCELED_BY_USER(0),
    INVALID_SESSION(1),
    INVALID_GESTURES_NUMBER(2),
    API_ERROR(3),
    CAMERA_UNAVAILABLE(4),
    LIVE_SELFIE_VALIDATION_ERROR(5),
    DIGITAL_DOCUMENT_VALIDATION_ERROR(6),
    COLLECT_DOCUMENT_VALIDATION_ERROR(7),
    CONNECTION_ERROR(8),
    PERMISSION_DENIED(9),
    GPS_DISABLED(10),
    GPS_ERROR(11),
    PUBLIC_IP_PROBLEM(12),
    ONE_TIME_CODE_ERROR(13),
    COLLECT_SELFIE_VALIDATION_ERROR(14),
    INVALID_CPF(15),
    COLLECT_OCR_ERROR(16),
    UNKNOWN_ERROR(17);

    companion object {
        fun ofRaw(raw: Int): IdentifyErrorCodeEnum? {
            return values().firstOrNull { it.raw == raw }
        }

        fun fromNativeResult(result: NativeEnum?): IdentifyErrorCodeEnum? {
            return when (result) {
                NativeEnum.USER_CANCELLED -> CANCELED_BY_USER

                NativeEnum.INVALID_TOKEN,
                NativeEnum.EXPIRED_TOKEN -> INVALID_SESSION

                NativeEnum.LIVESELFIE_NUMBER_OF_GESTURES_FAILURE -> INVALID_GESTURES_NUMBER

                NativeEnum.INVALID_SERVER_RESPONSE -> API_ERROR

                NativeEnum.CAMERA_UNAVAILABLE,
                NativeEnum.HARDWARE_NOT_SUPPORTED -> CAMERA_UNAVAILABLE

                NativeEnum.LIVESELFIE_VALIDATION_FAILURE -> LIVE_SELFIE_VALIDATION_ERROR

                NativeEnum.COLLECT_SELFIE_FAILURE -> COLLECT_SELFIE_VALIDATION_ERROR

                NativeEnum.COLLECT_DIGITAL_DOCUMENT_FAILURE -> DIGITAL_DOCUMENT_VALIDATION_ERROR

                NativeEnum.DOCUMENT_VALIDATION_FAILURE -> COLLECT_DOCUMENT_VALIDATION_ERROR

                NativeEnum.CONNECTION_ERROR -> CONNECTION_ERROR

                NativeEnum.PERMISSION_DENIED -> PERMISSION_DENIED

                NativeEnum.GPS_DISABLED -> GPS_DISABLED

                NativeEnum.GPS_ERROR,
                NativeEnum.GPS_REQUEST_EXPIRED -> GPS_ERROR

                NativeEnum.GET_PUBLIC_IP_PROBLEM -> PUBLIC_IP_PROBLEM

                NativeEnum.VERIFY_PHONE_NUMBER_FAILURE,
                NativeEnum.VERIFY_EMAIL_FAILURE -> ONE_TIME_CODE_ERROR

                NativeEnum.LIVESELFIE_CPF_FAILURE,
                NativeEnum.COLLECT_SELFIE_CPF_FAILURE -> INVALID_CPF

                NativeEnum.COLLECT_DOCUMENT_OCR_FAILURE -> COLLECT_OCR_ERROR

                NativeEnum.UNKNOWN_ERROR -> UNKNOWN_ERROR

                else -> null
            }
        }
    }
}