package br.com.stoneage.identify.identify_sdk_flutter.errors

import br.com.stoneage.identify.identify_sdk_flutter.enums.DocumentValidationErrorEnum
import br.com.stoneage.identify.identify_sdk_flutter.enums.IdentifyErrorCodeEnum
import br.com.stoneage.identify.models.DocumentActivityErrorResult as NativeResult

data class CollectDocumentError(
    override val message: String,
    val validationErrors: List<DocumentValidationErrorEnum>? = null
) : IdentifyError(IdentifyErrorCodeEnum.COLLECT_DOCUMENT_VALIDATION_ERROR, message) {
    companion object {
        @Suppress("UNCHECKED_CAST")
        fun fromList(list: List<Any?>): CollectDocumentError {
            //NOTE: list[0] is the code but, in this class, the code always has the value
            // IdentifyErrorCodeEnum.COLLECT_DOCUMENT_VALIDATION_ERROR.
            val message = list[1] as String
            val validationErrors = list[2] as List<DocumentValidationErrorEnum>?
            return CollectDocumentError(message, validationErrors)
        }

        fun fromNativeResult(result: NativeResult): CollectDocumentError {
            return CollectDocumentError(
                message = result.errorMessage ?: "",
                //NOTE: Pigeon didn't create this map correctly. It is necessary to map
                // validationErrors using 'fromNativeEnum' method. Without the map, the application
                // doesn't understand the enum list and crashes.
                validationErrors = result.validationErrors?.let { validationErrors ->
                    validationErrors.map { validationError ->
                        DocumentValidationErrorEnum.fromNativeEnum(validationError)
                    }
                }
            )
        }
    }

    override fun toList(): List<Any?> {
        //NOTE: Pigeon didn't create this map correctly. It is necessary to map validationErrors to
        // 'raw'. Without the map, the application doesn't understand the enum list and crashes.
        return listOf(
            code.raw,
            message,
            validationErrors?.map { it.raw }?.toList(),
        )
    }
}