package br.com.stoneage.identify.identify_sdk_flutter.errors

import br.com.stoneage.identify.enums.ErrorStatusEnum
import br.com.stoneage.identify.identify_sdk_flutter.enums.IdentifyErrorCodeEnum
import br.com.stoneage.identify.models.DocumentActivityErrorResult as DocumentNativeResult
import br.com.stoneage.identify.models.CollectSelfieResultError as SelfieNativeResult

open class IdentifyError(
    open val code: IdentifyErrorCodeEnum,
    override val message: String
) : Throwable(message) {
    companion object {
        fun fromList(list: List<Any?>): IdentifyError {
            val code = IdentifyErrorCodeEnum.ofRaw(list[0] as Int)!!
            val message = list[1] as String
            return IdentifyError(code, message)
        }

        //NOTE: `result` must be of type Any because the native result error classes don't have a
        // superclass.
        fun fromNativeResult(
            errorStatus: ErrorStatusEnum?,
            errorMessage: String?,
            result: Any
        ): IdentifyError {
            return when (val code = IdentifyErrorCodeEnum.fromNativeResult(errorStatus)) {
                IdentifyErrorCodeEnum.COLLECT_SELFIE_VALIDATION_ERROR -> CollectSelfieError.fromNativeResult(
                    result as SelfieNativeResult
                )

                IdentifyErrorCodeEnum.INVALID_CPF -> IdentifyError(
                    IdentifyErrorCodeEnum.INVALID_CPF,
                    errorMessage!!
                )

                IdentifyErrorCodeEnum.COLLECT_DOCUMENT_VALIDATION_ERROR -> CollectDocumentError.fromNativeResult(
                    result as DocumentNativeResult
                )

                else -> IdentifyError(
                    code = code!!,
                    message = errorMessage ?: "",
                )
            }
        }
    }

    open fun toList(): List<Any?> {
        return listOf<Any?>(
            code.raw,
            message,
        )
    }
}