package br.com.stoneage.identify.identify_sdk_flutter.models

import br.com.stoneage.identify.identify_sdk_flutter.enums.BiometricValidationProbabilityEnum
import br.com.stoneage.identify.models.BiometricResult as NativeResult

/** Generated class from Pigeon that represents data sent in messages. */
data class BiometricResult(
    val isAvailable: Boolean,
    val identityConfirmationProbability: BiometricValidationProbabilityEnum? = null,
    val serviceProviderAvailable: Boolean? = null,
    val similarity: Double? = null
) {
    companion object {
        fun fromList(list: List<Any?>): BiometricResult {
            val isAvailable = list[0] as Boolean
            val identityConfirmationProbability: BiometricValidationProbabilityEnum? =
                (list[1] as Int?)?.let {
                    BiometricValidationProbabilityEnum.ofRaw(it)
                }
            val serviceProviderAvailable = list[2] as Boolean?
            val similarity = list[3] as Double?
            return BiometricResult(
                isAvailable,
                identityConfirmationProbability,
                serviceProviderAvailable,
                similarity
            )
        }

        fun fromNativeResult(result: NativeResult?): BiometricResult? {
            return result?.let {
                BiometricResult(
                    isAvailable = it.isAvailable,
                    identityConfirmationProbability = BiometricValidationProbabilityEnum.fromNativeEnum(
                        it.identityConfirmationProbability
                    ),
                    serviceProviderAvailable = it.serviceProviderAvailable,
                    similarity = it.similarity,
                )
            }
        }
    }

    fun toList(): List<Any?> {
        return listOf<Any?>(
            isAvailable,
            identityConfirmationProbability?.raw,
            serviceProviderAvailable,
            similarity,
        )
    }
}