package br.com.stoneage.identify.identify_sdk_flutter.models

import br.com.stoneage.identify.identify_sdk_flutter.enums.DocumentTypeEnum
import br.com.stoneage.identify.identify_sdk_flutter.utils.FileUtils
import br.com.stoneage.identify.models.DocumentActivityResult as NativeResult

/** Generated class from Pigeon that represents data sent in messages. */
data class CollectDocumentResult(
    val documentType: DocumentTypeEnum,
    val documentInfo: List<DocumentInfo>,
    val image: String,
    val requestId: String,
    val optionalValidations: DocumentOptionalValidationsResult? = null
) {
    companion object {
        @Suppress("UNCHECKED_CAST")
        fun fromList(list: List<Any?>): CollectDocumentResult {
            val documentType = DocumentTypeEnum.ofRaw(list[0] as Int)!!
            val documentInfo = list[1] as List<DocumentInfo>
            val image = list[2] as String
            val requestId = list[3] as String
            val optionalValidations = (list[4] as List<Any?>?)?.let {
                DocumentOptionalValidationsResult.fromList(it)
            }
            return CollectDocumentResult(
                documentType,
                documentInfo,
                image,
                requestId,
                optionalValidations
            )
        }

        fun fromNativeResult(result: NativeResult): CollectDocumentResult {
            return CollectDocumentResult(
                requestId = result.requestId!!,
                documentType = DocumentTypeEnum.fromNativeEnum(result.documentType)!!,
                documentInfo = result.info?.let { documentInfo ->
                    listOf(DocumentInfo.fromNativeResult(documentInfo))
                } ?: listOf(),
                image = FileUtils.fileToBase64(result.imageFile),
                optionalValidations = DocumentOptionalValidationsResult.fromNativeResult(result.optionalValidations)
            )
        }
    }

    fun toList(): List<Any?> {
        return listOf(
            documentType.raw,
            documentInfo,
            image,
            requestId,
            optionalValidations?.toList(),
        )
    }
}