package br.com.stoneage.identify.identify_sdk_flutter.models

import br.com.stoneage.identify.enums.DocumentOcrStatusEnum
import br.com.stoneage.identify.identify_sdk_flutter.enums.OcrStatusEnum
import br.com.stoneage.identify.models.DocumentOcrResult
import br.com.stoneage.identify.models.DocumentOcrResultInfo
import br.com.stoneage.identify.models.DocumentOcrResultMessage
import br.com.stoneage.identify.models.DocumentOcrResponse as NativeResult

/** Generated class from Pigeon that represents data sent in messages. */
data class CollectOcrResult(
    val status: OcrStatusEnum,
    val ocrInfo: OcrInfo? = null,
    val msg: String? = null
) {
    companion object {
        fun fromList(list: List<Any?>): CollectOcrResult {
            val status = OcrStatusEnum.ofRaw(list[0] as Int)!!
            val ocrInfo = (list[1] as List<Any?>?)?.let {
                OcrInfo.fromList(it)
            }
            val msg = list[2] as String?
            return CollectOcrResult(status, ocrInfo, msg)
        }

        fun fromNativeResult(response: NativeResult): CollectOcrResult {
            if (response.status == null) {
                return CollectOcrResult(OcrStatusEnum.ERROR)
            }

            if (response.status == DocumentOcrStatusEnum.IN_PROGRESS) {
                return CollectOcrResult(
                    status = OcrStatusEnum.fromNativeEnum(response.status!!),
                    msg = (response.result as DocumentOcrResultMessage).msg
                )
            }

            if (response.status == DocumentOcrStatusEnum.FINISHED) {
                return CollectOcrResult(
                    status = OcrStatusEnum.fromNativeEnum(response.status!!),
                    ocrInfo = OcrInfo.fromNativeResult(response.result as DocumentOcrResultInfo)
                )
            }

            return CollectOcrResult(status = OcrStatusEnum.ERROR)
        }
    }

    fun toList(): List<Any?> {
        return listOf(
            status.raw,
            ocrInfo?.toList(),
            msg,
        )
    }
}