package br.com.stoneage.identify.identify_sdk_flutter.models

import br.com.stoneage.identify.models.PhoneInformation as NativeResult

/** Generated class from Pigeon that represents data sent in messages. */
data class DeviceInformationResult(
    val vendorId: String,
    val deviceModel: String,
    val manufacturer: String,
    val systemName: String,
    val usesMetricSystem: Boolean,
    val isRooted: Boolean,
    val timeZone: String,
    val preferredLanguages: List<String?>,
    val carriers: List<String?>,
    val flutterSdkVersion: String? = null,
    val deviceStorage: String? = null,
    val currencyCode: String? = null,
    val location: LocationData? = null,
    val wiFiIp: String? = null,
    val publicIp: String? = null,
    val nativeSdkVersion: String? = null,
    val androidOnly: AndroidOnlyDeviceInformation? = null,
    //NOTE: This property is only present because Pigeon uses positional values, i.e., it expects
    //a list with 18 elements. Since we don't need to declare the IosOnlyDeviceInformation class,
    //the type Nothing? was set to this property. Also, all return values of this property are null.
    val iosOnly: Nothing? = null,
) {
    companion object {
        @Suppress("UNCHECKED_CAST")
        fun fromList(list: List<Any?>): DeviceInformationResult {
            val vendorId = list[0] as String
            val deviceModel = list[1] as String
            val manufacturer = list[2] as String
            val systemName = list[3] as String
            val usesMetricSystem = list[4] as Boolean
            val isRooted = list[5] as Boolean
            val timeZone = list[6] as String
            val preferredLanguages = list[7] as List<String?>
            val carriers = list[8] as List<String?>
            val flutterSdkVersion = list[9] as String?
            val deviceStorage = list[10] as String?
            val currencyCode = list[11] as String?
            val location: LocationData? = (list[12] as List<Any?>?)?.let {
                LocationData.fromList(it)
            }
            val wiFiIp = list[13] as String?
            val publicIp = list[14] as String?
            val nativeSdkVersion = list[15] as String?
            val androidOnly: AndroidOnlyDeviceInformation? = (list[16] as List<Any?>?)?.let {
                AndroidOnlyDeviceInformation.fromList(it)
            }

            return DeviceInformationResult(
                vendorId,
                deviceModel,
                manufacturer,
                systemName,
                usesMetricSystem,
                isRooted,
                timeZone,
                preferredLanguages,
                carriers,
                flutterSdkVersion,
                deviceStorage,
                currencyCode,
                location,
                wiFiIp,
                publicIp,
                nativeSdkVersion,
                androidOnly
            )
        }

        fun fromNativeResult(phoneInformation: NativeResult): DeviceInformationResult {
            return DeviceInformationResult(
                vendorId = phoneInformation.androidId,
                deviceModel = phoneInformation.deviceModel,
                manufacturer = phoneInformation.manufacturer,
                systemName = phoneInformation.systemName,
                deviceStorage = phoneInformation.internalMemorySize,
                currencyCode = phoneInformation.currencyCode,
                usesMetricSystem = phoneInformation.isMetricSystem,
                isRooted = phoneInformation.isRooted,
                timeZone = phoneInformation.timeZone.id,
                preferredLanguages = listOf(phoneInformation.preferredLanguage),
                location = LocationData.fromNativeResult(phoneInformation.location),
                carriers = listOf(phoneInformation.carrier),
                wiFiIp = phoneInformation.wifiIp,
                publicIp = phoneInformation.publicIp,
                nativeSdkVersion = phoneInformation.sdkVersion,
                androidOnly = AndroidOnlyDeviceInformation.fromNativeResult(phoneInformation),
            )
        }
    }

    fun toList(): List<Any?> {
        return listOf(
            vendorId,
            deviceModel,
            manufacturer,
            systemName,
            usesMetricSystem,
            isRooted,
            timeZone,
            preferredLanguages,
            carriers,
            flutterSdkVersion,
            deviceStorage,
            currencyCode,
            location?.toList(),
            wiFiIp,
            publicIp,
            nativeSdkVersion,
            androidOnly?.toList(),
            iosOnly
        )
    }
}