package br.com.stoneage.identify.identify_sdk_flutter.models

import br.com.stoneage.identify.identify_sdk_flutter.enums.DocumentClassificationEnum
import br.com.stoneage.identify.identify_sdk_flutter.enums.DocumentSideEnum

import br.com.stoneage.identify.models.DocumentInfo as NativeResult

/** Generated class from Pigeon that represents data sent in messages. */
data class DocumentInfo (
    val confidence: Double,
    val cropping: DocumentCropping,
    val boundingBox: BoundingBox,
    val classification: DocumentClassificationEnum? = null,
    val documentSide: DocumentSideEnum? = null,
    val documentName: String? = null
) {
    companion object {
        fun fromList(list: List<Any?>): DocumentInfo {
            val confidence = list[0] as Double
            val cropping = DocumentCropping.fromList(list[1] as List<Any?>)
            val boundingBox = BoundingBox.fromList(list[2] as List<Any?>)
            val classification: DocumentClassificationEnum? = (list[3] as Int?)?.let {
                DocumentClassificationEnum.ofRaw(it)
            }
            val documentSide: DocumentSideEnum? = (list[4] as Int?)?.let {
                DocumentSideEnum.ofRaw(it)
            }
            val documentName = list[5] as String?
            return DocumentInfo(
                confidence,
                cropping,
                boundingBox,
                classification,
                documentSide,
                documentName
            )
        }

        fun fromNativeResult(result: NativeResult): DocumentInfo {
            return DocumentInfo(
                confidence = result.confidence,
                cropping = DocumentCropping.fromNativeResult(result),
                boundingBox = BoundingBox.fromNativeResult(result.boundingBox),
                classification = DocumentClassificationEnum.fromNativeEnum(result.classification),
                documentSide = DocumentSideEnum.fromNativeEnum(result.documentSide),
                documentName = result.documentName
            )
        }
    }

    fun toList(): List<Any?> {
        return listOf(
            confidence,
            cropping.toList(),
            boundingBox.toList(),
            classification?.raw,
            documentSide?.raw,
            documentName,
        )
    }
}