package br.com.stoneage.identify.identify_sdk_flutter.models

import android.location.Location as NativeResult
import android.os.Build

/** Generated class from Pigeon that represents data sent in messages. */
data class LocationData(
    val longitude: Double,
    val latitude: Double,
    val timestamp: Long,
    val altitude: Double? = null,
    val accuracy: Double? = null,
    val speed: Double? = null,
    val speedAccuracy: Double? = null,
    val bearing: Double? = null,
    val bearingAccuracy: Double? = null,
) {
    companion object {
        fun fromList(list: List<Any?>): LocationData {
            val longitude = list[0] as Double
            val latitude = list[1] as Double
            val timestamp = list[2].let { if (it is Int) it.toLong() else it as Long }
            val altitude = list[3] as Double?
            val accuracy = list[4] as Double?
            val speed = list[5] as Double?
            val speedAccuracy = list[6] as Double?
            val bearing = list[7] as Double?
            val bearingAccuracy = list[8] as Double?
            return LocationData(
                longitude,
                latitude,
                timestamp,
                altitude,
                accuracy,
                speed,
                speedAccuracy,
                bearing,
                bearingAccuracy,
            )
        }

        private fun getSpeedAccuracy(location: NativeResult): Double? {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                return location.speedAccuracyMetersPerSecond.toDouble()
            }

            return null
        }

        private fun getBearingAccuracy(location: NativeResult): Double? {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                return location.bearingAccuracyDegrees.toDouble()
            }

            return null
        }

        fun fromNativeResult(location: NativeResult?): LocationData? {
            return location?.let {
                LocationData(
                    longitude = it.longitude,
                    latitude = it.latitude,
                    altitude = it.altitude,
                    accuracy = it.accuracy.toDouble(),
                    speed = it.speed.toDouble(),
                    bearing = it.bearing.toDouble(),
                    timestamp = it.time,
                    speedAccuracy = getSpeedAccuracy(it),
                    bearingAccuracy = getBearingAccuracy(it),
                )
            }
        }
    }

    fun toList(): List<Any?> {
        return listOf<Any?>(
            longitude,
            latitude,
            timestamp,
            altitude,
            accuracy,
            speed,
            speedAccuracy,
            bearing,
            bearingAccuracy,
        )
    }
}
