package br.com.stoneage.identify.identify_sdk_flutter.models

import br.com.stoneage.identify.identify_sdk_flutter.enums.DocumentTypeEnum
import br.com.stoneage.identify.models.DocumentOcrResultInfo as NativeResult

/** Generated class from Pigeon that represents data sent in messages. */
data class OcrInfo(
    val expeditionDate: String? = null,
    val location: String? = null,
    val type: DocumentTypeEnum? = null,
    val issuanceDate: String? = null,
    val placeOfBirth: String? = null,
    val documentOrigin: String? = null,
    val ownerSigns: Boolean? = null,
    val firstFiliation: String? = null,
    val secondFiliation: String? = null,
    val registerNumber: String? = null,
    val generalRegisterNumber: String? = null,
    val dateOfBirth: String? = null,
    val drivingLicenseCategory: String? = null,
    val fullName: String? = null,
    val drivingLicenseFirstIssuanceDate: String? = null,
    val cpf: String? = null,
    val expirationDate: String? = null,
    val expeditionIssuer: String? = null,
    val expeditionIssuerState: String? = null,
    val socialName: String? = null,
    val gender: String? = null,
    val nationality: String? = null,
    val classification: String? = null,
    val residencePeriod: String? = null,
    val surname: String? = null

) {
    companion object {
        fun fromList(list: List<Any?>): OcrInfo {
            val expeditionDate = list[0] as String?
            val location = list[1] as String?
            val type: DocumentTypeEnum? = (list[2] as Int?)?.let {
                DocumentTypeEnum.ofRaw(it)
            }
            val issuanceDate = list[3] as String?
            val placeOfBirth = list[4] as String?
            val documentOrigin = list[5] as String?
            val ownerSigns = list[6] as Boolean?
            val firstFiliation = list[7] as String?
            val secondFiliation = list[8] as String?
            val registerNumber = list[9] as String?
            val generalRegisterNumber = list[10] as String?
            val dateOfBirth = list[11] as String?
            val drivingLicenseCategory = list[12] as String?
            val fullName = list[13] as String?
            val drivingLicenseFirstIssuanceDate = list[14] as String?
            val cpf = list[15] as String?
            val expirationDate = list[16] as String?
            val expeditionIssuer = list[17] as String?
            val expeditionIssuerState = list[18] as String?
            val socialName = list[19] as String?
            val gender = list[20] as String?
            val nationality = list[21] as String?
            val classification = list[22] as String?
            val residencePeriod = list[23] as String?
            val surname = list[24] as String?
            return OcrInfo(
                expeditionDate,
                location,
                type,
                issuanceDate,
                placeOfBirth,
                documentOrigin,
                ownerSigns,
                firstFiliation,
                secondFiliation,
                registerNumber,
                generalRegisterNumber,
                dateOfBirth,
                drivingLicenseCategory,
                fullName,
                drivingLicenseFirstIssuanceDate,
                cpf,
                expirationDate,
                expeditionIssuer,
                expeditionIssuerState,
                socialName,
                gender,
                nationality,
                classification,
                residencePeriod,
                surname
            )
        }

        fun fromNativeResult(result: NativeResult): OcrInfo {
            return OcrInfo(
                expeditionDate = result.dataExpedicao,
                location = result.local,
                type = DocumentTypeEnum.fromNativeEnum(result.type),
                issuanceDate = result.emissao,
                placeOfBirth = result.naturalidade,
                documentOrigin = result.documentoOrigem,
                ownerSigns = getOwnerSigns(result.naoAssina),
                firstFiliation = getFirstFiliation(result),
                secondFiliation = getSecondFiliation(result),
                registerNumber = result.numeroRegistro,
                generalRegisterNumber = result.registroGeral,
                dateOfBirth = result.dataNascimento,
                drivingLicenseCategory = result.categoriaHabilitacao,
                fullName = result.nome,
                drivingLicenseFirstIssuanceDate = result.primeiraHabilitacao,
                cpf = result.cpf,
                expirationDate = result.validade,
                expeditionIssuer = getExpeditionIssuer(result),
                expeditionIssuerState = result.ufOrgaoExpedidor,
                socialName = result.nomeSocial,
                gender = result.sexo,
                nationality = result.nacionalidade,
                classification = result.classificacao,
                residencePeriod = result.prazo,
                surname = result.sobrenome,
            )
        }

        private fun getOwnerSigns(result: String?): Boolean? {
            if (result.isNullOrEmpty()) {
                return null
            }

            if (result.lowercase() == "true") {
                return false
            }

            return true
        }

        private fun getExpeditionIssuer(result: NativeResult): String? {
            if (result.orgaoExpedidor != null) {
                return (result.orgaoExpedidor + " " + (result.orgaoExpedidorSecondary ?: "")).trim()
            }

            if (result.orgExpedidor != null) {
                return (result.orgExpedidor + " " + (result.orgExpedidorSecondary ?: "")).trim()
            }

            return null
        }

        private fun getFirstFiliation(result: NativeResult): String? {
            if (result.filiacao1 != null) {
                return result.filiacao1
            }

            if (result.filiacao1Main != null) {
                return (result.filiacao1Main + " " + (result.filiacao1Secondary ?: "")).trim()
            }

            return null
        }

        private fun getSecondFiliation(result: NativeResult): String? {
            if (result.filiacao2 != null) {
                return result.filiacao2
            }

            if (result.filiacao2Main != null) {
                return (result.filiacao2Main + " " + (result.filiacao2Secondary ?: "")).trim()
            }

            return null
        }
    }

    fun toList(): List<Any?> {
        return listOf<Any?>(
            expeditionDate,
            location,
            type?.raw,
            issuanceDate,
            placeOfBirth,
            documentOrigin,
            ownerSigns,
            firstFiliation,
            secondFiliation,
            registerNumber,
            generalRegisterNumber,
            dateOfBirth,
            drivingLicenseCategory,
            fullName,
            drivingLicenseFirstIssuanceDate,
            cpf,
            expirationDate,
            expeditionIssuer,
            expeditionIssuerState,
            socialName,
            gender,
            nationality,
            classification,
            residencePeriod,
            surname,
        )
    }
}