package br.com.stoneage.identify.identify_sdk_flutter.models.common

import android.app.Activity
import android.content.Intent
import androidx.activity.ComponentActivity
import androidx.activity.result.ActivityResult
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.contract.ActivityResultContracts
import br.com.stoneage.identify.identify_sdk_flutter.errors.UnknownError

abstract class IdentifySdkPluginActivityResult<T> {

    private var mActivity: Activity? = null
    private var mActivityResultContract: ActivityResultLauncher<Intent>? = null

    var activity: Activity?
        get() = mActivity
        set(value) {
            mActivity = value
            //NOTE: The contract needs to be assigned before any method calls
            mActivityResultContract = value?.let {
                (it as ComponentActivity).registerForActivityResult(
                    ActivityResultContracts.StartActivityForResult(),
                    ::onActivityResult
                )
            }
        }

    protected lateinit var mCallback: (Result<T>) -> Unit

    protected fun startActivityForResult(intent: Intent) {
        mActivityResultContract?.launch(intent)
    }

    private fun onActivityResult(result: ActivityResult) {
        return when (result.resultCode) {
            Activity.RESULT_OK -> handleResultOk(result.data)
            Activity.RESULT_CANCELED -> handleResultCanceled(result.data)
            else -> mCallback(Result.failure(UnknownError()))
        }
    }

    protected abstract fun handleResultOk(data: Intent?)
    protected abstract fun handleResultCanceled(data: Intent?)
}