package br.com.stoneage.identify.identify_sdk_flutter.models.plugins

import br.com.stoneage.identify.identify_sdk_flutter.codecs.IdentifySdkPluginCoreCodec
import br.com.stoneage.identify.identify_sdk_flutter.models.IdentifyTheme
import br.com.stoneage.identify.identify_sdk_flutter.utils.WrappingUtils
import io.flutter.plugin.common.BasicMessageChannel
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MessageCodec

interface IIdentifySdkPluginCore {
    fun initializeSession(
        token: String,
        stage: String,
        theme: IdentifyTheme?,
        callback: (Result<Unit>) -> Unit
    )

    companion object {
        /** The codec used by IdentifySdkPluginCore. */
        private val codec: MessageCodec<Any?> by lazy {
            IdentifySdkPluginCoreCodec
        }

        /** Sets up an instance of `IdentifySdkPluginCore` to handle messages through the `binaryMessenger`. */
        fun setUp(binaryMessenger: BinaryMessenger, api: IIdentifySdkPluginCore?) {
            run {
                val channel = BasicMessageChannel<Any?>(
                    binaryMessenger,
                    "dev.flutter.pigeon.identify_sdk_flutter.IdentifySdkPluginCore.initializeSession",
                    codec
                )
                if (api != null) {
                    channel.setMessageHandler { message, reply ->
                        val args = message as List<Any?>
                        val tokenArg = args[0] as String
                        val stageArg = args[1] as String
                        val themeArg = args[2] as IdentifyTheme?
                        api.initializeSession(
                            tokenArg,
                            stageArg,
                            themeArg
                        ) { result: Result<Unit> ->
                            val error = result.exceptionOrNull()
                            if (error != null) {
                                reply.reply(WrappingUtils.wrapError(error))
                            } else {
                                reply.reply(WrappingUtils.wrapResult(null))
                            }
                        }
                    }
                } else {
                    channel.setMessageHandler(null)
                }
            }
        }
    }
}