package br.com.stoneage.identify.identify_sdk_flutter.models.plugins

import br.com.stoneage.identify.identify_sdk_flutter.codecs.IdentifySdkPluginDeviceInformationCodec
import br.com.stoneage.identify.identify_sdk_flutter.models.DeviceInformationResult
import br.com.stoneage.identify.identify_sdk_flutter.utils.WrappingUtils
import io.flutter.plugin.common.BasicMessageChannel
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MessageCodec

interface IIdentifySdkPluginDeviceInformation {
    fun getDeviceInformation(
        geolocation: Boolean, callback: (Result<DeviceInformationResult>) -> Unit
    )

    companion object {
        /** The codec used by IdentifySdkPluginDeviceInformation. */
        private val codec: MessageCodec<Any?> by lazy {
            IdentifySdkPluginDeviceInformationCodec
        }

        /** Sets up an instance of `IdentifySdkPluginDeviceInformation` to handle messages through the `binaryMessenger`. */
        fun setUp(binaryMessenger: BinaryMessenger, api: IIdentifySdkPluginDeviceInformation?) {
            run {
                val channel = BasicMessageChannel<Any?>(
                    binaryMessenger,
                    "dev.flutter.pigeon.identify_sdk_flutter.IdentifySdkPluginDeviceInformation.getDeviceInformation",
                    codec
                )
                if (api != null) {
                    channel.setMessageHandler { message, reply ->
                        val args = message as List<Any?>
                        val geolocationArg = args[0] as Boolean
                        api.getDeviceInformation(geolocationArg) { result: Result<DeviceInformationResult> ->
                            val error = result.exceptionOrNull()
                            if (error != null) {
                                reply.reply(WrappingUtils.wrapError(error))
                            } else {
                                val data = result.getOrNull()
                                reply.reply(WrappingUtils.wrapResult(data))
                            }
                        }
                    }
                } else {
                    channel.setMessageHandler(null)
                }
            }
        }
    }
}
