package br.com.stoneage.identify.identify_sdk_flutter.models.plugins

import br.com.stoneage.identify.identify_sdk_flutter.codecs.IdentifySdkPluginDocumentCodec
import br.com.stoneage.identify.identify_sdk_flutter.enums.DocumentCaptureModeEnum
import br.com.stoneage.identify.identify_sdk_flutter.enums.DocumentSideEnum
import br.com.stoneage.identify.identify_sdk_flutter.models.CollectDocumentResult
import br.com.stoneage.identify.identify_sdk_flutter.models.DocumentOptionalValidations
import br.com.stoneage.identify.identify_sdk_flutter.utils.WrappingUtils
import io.flutter.plugin.common.BasicMessageChannel
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MessageCodec

/** Generated interface from Pigeon that represents a handler of messages from Flutter. */
interface IIdentifySdkPluginDocument {
    fun collect(
        documentSide: DocumentSideEnum,
        captureMode: DocumentCaptureModeEnum?,
        optionalValidations: DocumentOptionalValidations?,
        callback: (Result<CollectDocumentResult>) -> Unit
    )

    companion object {
        /** The codec used by IdentifySdkPluginDocument. */
        private val codec: MessageCodec<Any?> by lazy {
            IdentifySdkPluginDocumentCodec
        }

        /** Sets up an instance of `IdentifySdkPluginDocument` to handle messages through the `binaryMessenger`. */
        fun setUp(binaryMessenger: BinaryMessenger, api: IIdentifySdkPluginDocument?) {
            run {
                val channel = BasicMessageChannel<Any?>(
                    binaryMessenger,
                    "dev.flutter.pigeon.identify_sdk_flutter.IdentifySdkPluginDocument.collect",
                    codec
                )
                if (api != null) {
                    channel.setMessageHandler { message, reply ->
                        val args = message as List<Any?>
                        val documentSideArg = DocumentSideEnum.ofRaw(args[0] as Int)!!
                        val captureModeArg =
                            if (args[1] == null) null else DocumentCaptureModeEnum.ofRaw(args[1] as Int)
                        val optionalValidationsArg = args[2] as DocumentOptionalValidations?
                        api.collect(
                            documentSideArg,
                            captureModeArg,
                            optionalValidationsArg
                        ) { result: Result<CollectDocumentResult> ->
                            val error = result.exceptionOrNull()
                            if (error != null) {
                                reply.reply(WrappingUtils.wrapError(error))
                            } else {
                                val data = result.getOrNull()
                                reply.reply(WrappingUtils.wrapResult(data))
                            }
                        }
                    }
                } else {
                    channel.setMessageHandler(null)
                }
            }
        }
    }
}