package br.com.stoneage.identify.identify_sdk_flutter.models.plugins

import br.com.stoneage.identify.identify_sdk_flutter.codecs.IdentifySdkPluginOcrCodec
import br.com.stoneage.identify.identify_sdk_flutter.models.CollectOcrResult
import br.com.stoneage.identify.identify_sdk_flutter.utils.WrappingUtils
import io.flutter.plugin.common.BasicMessageChannel
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MessageCodec

/** Generated interface from Pigeon that represents a handler of messages from Flutter. */
interface IIdentifySdkPluginOcr {
    fun collect(requestId: String, callback: (Result<CollectOcrResult>) -> Unit)

    companion object {
        /** The codec used by IdentifySdkPluginOcr. */
        private val codec: MessageCodec<Any?> by lazy {
            IdentifySdkPluginOcrCodec
        }

        /** Sets up an instance of `IdentifySdkPluginOcr` to handle messages through the `binaryMessenger`. */
        fun setUp(binaryMessenger: BinaryMessenger, api: IIdentifySdkPluginOcr?) {
            run {
                val channel = BasicMessageChannel<Any?>(
                    binaryMessenger,
                    "dev.flutter.pigeon.identify_sdk_flutter.IdentifySdkPluginOcr.collect",
                    codec
                )
                if (api != null) {
                    channel.setMessageHandler { message, reply ->
                        val args = message as List<Any?>
                        val requestIdArg = args[0] as String
                        api.collect(requestIdArg) { result: Result<CollectOcrResult> ->
                            val error = result.exceptionOrNull()
                            if (error != null) {
                                reply.reply(WrappingUtils.wrapError(error))
                            } else {
                                val data = result.getOrNull()
                                reply.reply(WrappingUtils.wrapResult(data))
                            }
                        }
                    }
                } else {
                    channel.setMessageHandler(null)
                }
            }
        }
    }
}