package br.com.stoneage.identify.identify_sdk_flutter.plugins

import android.Manifest
import android.app.Activity
import android.content.pm.PackageManager
import androidx.activity.ComponentActivity
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.contract.ActivityResultContracts
import androidx.core.app.ActivityCompat
import br.com.stoneage.identify.enums.ErrorStatusEnum
import br.com.stoneage.identify.exceptions.PhoneInformationException
import br.com.stoneage.identify.identify_sdk_flutter.errors.IdentifyError
import br.com.stoneage.identify.identify_sdk_flutter.models.DeviceInformationResult
import br.com.stoneage.identify.identify_sdk_flutter.models.plugins.IIdentifySdkPluginDeviceInformation
import br.com.stoneage.identify.models.PhoneInformation
import br.com.stoneage.identify.models.PhoneInformationDelegate
import br.com.stoneage.identify.sdk.STACollectData

class IdentifySdkPluginDeviceInformation : IIdentifySdkPluginDeviceInformation,
    PhoneInformationDelegate {

    private var mActivity: Activity? = null
    private var mActivityRequestPermissionContract: ActivityResultLauncher<String>? = null
    var activity: Activity?
        get() = mActivity
        set(value) {
            mActivity = value
            //NOTE: The contract needs to be assigned before any method calls
            mActivityRequestPermissionContract = value?.let {
                (it as ComponentActivity).registerForActivityResult(
                    ActivityResultContracts.RequestPermission(),
                    ::onRequestPermissionResult
                )
            }
        }
    private lateinit var mCallback: (Result<DeviceInformationResult>) -> Unit
    override fun getDeviceInformation(
        geolocation: Boolean, callback: (Result<DeviceInformationResult>) -> Unit
    ) {
        mCallback = callback

        if (geolocation) {
            collectDataWithGps()
        } else {
            collectDataWithoutGps()
        }
    }

    private fun collectDataWithGps() {
        activity?.let {
            if (hasLocationPermission(it)) {
                STACollectData.getPhoneInformation(this, true)
            } else {
                mActivityRequestPermissionContract?.launch(Manifest.permission.ACCESS_FINE_LOCATION)
            }
        }
    }

    private fun collectDataWithoutGps() {
        STACollectData.getPhoneInformation(this, false)
    }

    private fun hasLocationPermission(activity: Activity): Boolean {
        return (ActivityCompat.checkSelfPermission(
                activity, Manifest.permission.ACCESS_FINE_LOCATION
            ) == PackageManager.PERMISSION_GRANTED ||
                ActivityCompat.checkSelfPermission(
                activity, Manifest.permission.ACCESS_COARSE_LOCATION
            ) == PackageManager.PERMISSION_GRANTED
        )
    }

    override fun phoneInformationCallback(phoneInformation: PhoneInformation) {
        mCallback(Result.success(DeviceInformationResult.fromNativeResult(phoneInformation)))
    }

    override fun phoneInformationCallbackError(phoneInformationException: PhoneInformationException) {
        mCallback(
            Result.failure(
                IdentifyError.fromNativeResult(
                    phoneInformationException.errorStatusEnum,
                    phoneInformationException.message,
                    phoneInformationException
                )
            )
        )
    }

    private fun createPermissionError(): PhoneInformationException {
        val error = ErrorStatusEnum.PERMISSION_DENIED
        return PhoneInformationException(error, "Geolocation denied.")
    }

    private fun onRequestPermissionResult(isGranted: Boolean) {
        if (isGranted) {
            STACollectData.getPhoneInformation(this, true)
            return
        }

        val error = createPermissionError()
        mCallback(
            Result.failure(
                IdentifyError.fromNativeResult(
                    error.errorStatusEnum, error.message, error
                )
            )
        )
    }
}