package br.com.stoneage.identify.identify_sdk_flutter.plugins

import br.com.stoneage.identify.identify_sdk_flutter.enums.OcrStatusEnum
import br.com.stoneage.identify.identify_sdk_flutter.errors.IdentifyError
import br.com.stoneage.identify.identify_sdk_flutter.models.CollectOcrResult
import br.com.stoneage.identify.identify_sdk_flutter.models.plugins.IIdentifySdkPluginOcr
import br.com.stoneage.identify.models.DocumentOcrResponse
import br.com.stoneage.identify.models.errors.DocumentOcrError
import br.com.stoneage.identify.sdk.STACollectDocumentOcr

class IdentifySdkPluginOcr : IIdentifySdkPluginOcr {

    private lateinit var mCallback: (Result<CollectOcrResult>) -> Unit

    override fun collect(requestId: String, callback: (Result<CollectOcrResult>) -> Unit) {
        mCallback = callback

        val staCollectDocumentOcr = STACollectDocumentOcr()
        try {
            staCollectDocumentOcr.collectDocumentOcr(
                requestId,
                ::collectDocumentOcrCallback,
                ::collectDocumentOcrErrorCallback
            )
        } catch (ignored: Exception) {
            mCallback(
                Result.success(CollectOcrResult(OcrStatusEnum.ERROR))
            )
        }
    }

    private fun collectDocumentOcrCallback(response: DocumentOcrResponse) {
        mCallback(Result.success(CollectOcrResult.fromNativeResult(response)))
    }

    private fun collectDocumentOcrErrorCallback(error: DocumentOcrError) {
        mCallback(
            Result.failure(
                IdentifyError.fromNativeResult(
                    error.errorStatus,
                    error.errorMessage,
                    error
                )
            )
        )
    }
}