package br.com.stoneage.identify.identify_sdk_flutter.plugins

import android.content.Context
import android.content.Intent
import br.com.stoneage.identify.identify_sdk_flutter.errors.IdentifyError
import br.com.stoneage.identify.identify_sdk_flutter.errors.UnknownError
import br.com.stoneage.identify.identify_sdk_flutter.models.CollectSelfieParameters
import br.com.stoneage.identify.identify_sdk_flutter.models.CollectSelfieResult
import br.com.stoneage.identify.identify_sdk_flutter.models.common.IdentifySdkPluginActivityResult
import br.com.stoneage.identify.identify_sdk_flutter.models.plugins.IIdentifySdkPluginSelfie
import br.com.stoneage.identify.identify_sdk_flutter.utils.IntentUtils.getParcelable
import br.com.stoneage.identify.sdk.CollectSelfieActivity
import br.com.stoneage.identify.models.CollectSelfieResult as NativeResult
import br.com.stoneage.identify.models.CollectSelfieResultError as NativeErrorResult

class IdentifySdkPluginSelfie(private val context: Context) : IIdentifySdkPluginSelfie,
    IdentifySdkPluginActivityResult<CollectSelfieResult>() {
    override fun collect(
        parameters: CollectSelfieParameters?,
        callback: (Result<CollectSelfieResult>) -> Unit
    ) {
        mCallback = callback

        val intent = Intent(this.context, CollectSelfieActivity::class.java)

        parameters?.let {
            intent.putExtra("parameters", it.toNativeParameters())
        }

        startActivityForResult(intent)
    }

    override fun handleResultOk(data: Intent?) {
        val result = data?.getParcelable<NativeResult>("result")

        if (result == null) {
            mCallback(Result.failure(UnknownError()))
            return
        }

        val resultData = CollectSelfieResult.fromNativeResult(result)
        mCallback(Result.success(resultData))
    }

    override fun handleResultCanceled(data: Intent?) {
        return try {
            val error = data?.getParcelable<NativeErrorResult>("error")

            if (error?.errorStatus == null) {
                mCallback(Result.failure(UnknownError()))
                return
            }

            mCallback(
                Result.failure(
                    IdentifyError.fromNativeResult(
                        error.errorStatus,
                        error.errorMessage,
                        error
                    )
                )
            )
        } catch (e: Exception) {
            mCallback(Result.failure(e))
        }
    }
}