import STAIdentify

extension STADocumentOcr {
    func toOcrInfo() -> OcrInfo {
        return OcrInfo(
            expeditionDate: dataExpedicao,
            location: local,
            type: type?.toDocumentTypeEnum(),
            issuanceDate: emissao,
            placeOfBirth: naturalidade,
            documentOrigin: documentoOrigem,
            ownerSigns: ownerSigns,
            firstFiliation: firstFiliation,
            secondFiliation: secondFiliation,
            registerNumber: numeroRegistro,
            generalRegisterNumber: registroGeral,
            dateOfBirth: dataNascimento,
            drivingLicenseCategory: categoriaHabilitacao,
            fullName: nome,
            drivingLicenseFirstIssuanceDate: primeiraHabilitacao,
            cpf: cpf,
            expirationDate: validade,
            expeditionIssuer: expeditionIssuer,
            expeditionIssuerState: ufOrgaoExpedidor,
            socialName: nomeSocial,
            gender: sexo,
            nationality: nacionalidade,
            classification: classificacao,
            residencePeriod: prazo,
            surname: sobrenome
        )
    }

    fileprivate var ownerSigns: Bool? {
        get {
            guard let cantSign = self.naoAssina else {
                return nil
            }

            if cantSign.lowercased().trimmingCharacters(in: .whitespacesAndNewlines) == "true" {
                return false
            }

            return true
        }
    }

    fileprivate var firstFiliation: String? {
        if let filiacao1 = self.filiacao1 {
            return filiacao1
        }

        if let filiacao1Main = self.filiacao1Main {
            guard let filiacao1Secondary = self.filiacao1Secondary else {
                return filiacao1Main
            }

            return filiacao1Main + " " + filiacao1Secondary
        }

        return nil
    }

    fileprivate var secondFiliation: String? {
        if let filiacao2 = self.filiacao2 {
            return filiacao2
        }

        if let filiacao2Main = self.filiacao2Main {
            guard let filiacao2Secondary = self.filiacao2Secondary else {
                return filiacao2Main
            }

            return filiacao2Main + " " + filiacao2Secondary
        }

        return nil
    }

    fileprivate var expeditionIssuer: String? {
        get {
            if let orgaoExpedidor = self.orgaoExpedidor {
                guard let orgaoExpedidorSecondary = self.orgaoExpedidorSecondary else {
                    return orgaoExpedidor
                }

                return orgaoExpedidor + " " + orgaoExpedidorSecondary
            }

            if let orgExpedidor = self.orgExpedidor {
                guard let orgExpedidorSecondary = self.orgExpedidorSecondary else {
                    return orgExpedidor
                }

                return orgExpedidor + " " + orgExpedidorSecondary
            }

            return nil
        }
    }
}

