import STAIdentify

extension STAFingerprint {
    func toDeviceInformationResult() -> DeviceInformationResult {
        return DeviceInformationResult(
            vendorId: self.vendorIdentifier ?? "",
            deviceModel: self.deviceModel,
            manufacturer: "Apple",
            systemName: "\(self.systemName) \(self.systemVersion)",
            usesMetricSystem: self.usesMetricSystem,
            isRooted: self.deviceIsJailbroken,
            timeZone: self.timeZone.identifier,
            preferredLanguages: self.preferredLanguages,
            carriers: self.carriers.map { $0.carrierName }.filter{ $0 != nil },
            deviceStorage: self.deviceStorage,
            currencyCode: self.currencyCode,
            location: self.maybeToLocationData(),
            wiFiIp: self.wifiIP,
            publicIp: self.publicIP,
            nativeSdkVersion: self.sdkVersion,
            iosOnly: self.toIosOnlyDeviceInformation()
        )
    }

    func maybeToLocationData() -> LocationData? {
        guard case .success(let location) = self.location else {
            return nil
        }

        var speed: Double? = nil
        var speedAccuracy: Double? = nil
        var bearing: Double? = nil
        var bearingAccuracy: Double? = nil

        // NOTE: Negative values for 'speed', 'speedAccuracy', 'course' and 'courseAccuracy' represents
        // invalid data.
        // Reference: https://developer.apple.com/documentation/corelocation/cllocation/3524339-initwithcoordinate
        if location.data.speed >= 0 {
            speed = location.data.speed
        }

        if location.data.speedAccuracy >= 0 {
            speedAccuracy = location.data.speedAccuracy
        }

        if location.data.course >= 0 {
            bearing = location.data.course
        }

        if #available(iOS 13.4, *) {
            if location.data.courseAccuracy >= 0 {
                bearingAccuracy = location.data.courseAccuracy
            }
        }

        return LocationData(
            longitude: location.data.coordinate.longitude,
            latitude: location.data.coordinate.latitude,
            // NOTE: Android uses milliseconds since 1970 for its timestamp. To keep this value consistent,
            // we multiply our timestamp by 1000.
            timestamp: Int64(location.data.timestamp.timeIntervalSince1970) * 1000,
            altitude: location.data.altitude,
            accuracy: location.data.horizontalAccuracy,
            speed: speed,
            speedAccuracy: speedAccuracy,
            bearing: bearing,
            bearingAccuracy: bearingAccuracy
        )
    }

    func toIosOnlyDeviceInformation() -> IosOnlyDeviceInformation {
        var fullAccuracyPermission: Bool? = nil
        if case .success(let location) = self.location {
            fullAccuracyPermission = location.fullAccuracyPermission
        }

        return IosOnlyDeviceInformation (
            deviceName: self.deviceName,
            regionCode: self.regionCode,
            fullAccuracyPermission: fullAccuracyPermission
        )
    }
}
