extension UIColor {
    convenience init?(stringValue value: String) {
        let alpha, red, blue, green: CGFloat?

        guard value.hasPrefix("#") else {
            return nil
        }

        let colorValue = value.replacingOccurrences(of: "#", with: "").uppercased()
        let characters = Array(colorValue)

        // NOTE: Here we use ARGB instead of the more common RGBA format to maintain the same behavior as the Android
        // parseColor function: https://developer.android.com/reference/android/graphics/Color#parseColor(java.lang.String)
        switch characters.count {
        case 3: // #RGB
            alpha = 1.0
            red = colorComponentFromHex(characters[0..<1])
            green = colorComponentFromHex(characters[1..<2])
            blue = colorComponentFromHex(characters[2..<3])
        case 4: // #ARGB
            alpha = colorComponentFromHex(characters[0..<1])
            red = colorComponentFromHex(characters[1..<2])
            green = colorComponentFromHex(characters[2..<3])
            blue = colorComponentFromHex(characters[3..<4])
        case 6: // #RRGGBB
            alpha = 1.0
            red = colorComponentFromHex(characters[0..<2])
            green = colorComponentFromHex(characters[2..<4])
            blue = colorComponentFromHex(characters[4..<6])
        case 8: // ##AARRGGBB
            alpha = colorComponentFromHex(characters[0..<2])
            red = colorComponentFromHex(characters[2..<4])
            green = colorComponentFromHex(characters[4..<6])
            blue = colorComponentFromHex(characters[6..<8])
        default:
            return nil
        }

        guard let r = red,
              let g = green,
              let b = blue,
              let a = alpha else {

            return nil
        }

        self.init(red: r, green: g, blue: b, alpha: a)
    }
}

func colorComponentFromHex(_ chars: ArraySlice<Character>) -> CGFloat? {
    guard let hexValue = hexToInt(chars) else {
        return nil
    }

    if chars.count == 1 {
        return CGFloat(16 * hexValue + hexValue) / 255.0
    }

    return CGFloat(hexValue) / 255.0
}

func hexToInt(_ chars: ArraySlice<Character>) -> Int? {
    var accumulator = 0
    for char in chars {
        guard let hex = charToHex(char) else {
            return nil
        }

        accumulator = 16 * accumulator + hex
    }

    return accumulator
}

func charToHex(_ char: Character) -> Int? {
    return char.hexDigitValue
}
