import STAIdentify

/// Generated class from Pigeon that represents data sent in messages.
struct IdentifyTheme {
    var primaryColor: String
    var successColor: String
    var neutralColor: String

    static func fromList(_ list: [Any?]) -> IdentifyTheme? {
        let primaryColor = list[0] as! String
        let successColor = list[1] as! String
        let neutralColor = list[2] as! String

        return IdentifyTheme(
            primaryColor: primaryColor,
            successColor: successColor,
            neutralColor: neutralColor
        )
    }
    func toList() -> [Any?] {
        return [
            primaryColor,
            successColor,
            neutralColor,
        ]
    }
}

extension IdentifyTheme {
    static func toSTATheme(_ theme: Self?) -> STATheme {
        let result = Self.defaultTheme

        guard let theme = theme else {
            return result
        }

        if let primaryColor = UIColor(stringValue: theme.primaryColor) {
            result.primaryColor = STAColor(primaryColor)
        }

        if let successColor = UIColor(stringValue: theme.successColor) {
            result.successColor = STAColor(successColor)
        }

        if let neutralColor = UIColor(stringValue: theme.neutralColor) {
            result.neutralColor = STAColor(neutralColor)
        }

        return result
    }

    private static var defaultTheme: STATheme {
        return STATheme(primaryColor: .init(white: 0.15, alpha: 1.0),
                        successColor: .systemGreen,
                        neutralColor: .systemGray)
    }
}
