import STAIdentify

typealias DeviceInformationResponse = (Result<DeviceInformationResult, Error>) -> Void

class IdentifySdkPluginDeviceInformationImpl: IdentifySdkPluginDeviceInformation {
    func getDeviceInformation(geolocation: Bool,
                              completion: @escaping DeviceInformationResponse) {
        guard geolocation else {
            getFingerprint(geolocation, completion)
            return
        }

        STACollectData.requestLocationAuthorization { [weak self] authorizationStatus in
            switch authorizationStatus {
            case .denied, .restricted:
                STACollectData.stopListeningAuthorizationChange()

                completion(.failure(IdentifyException(code: .permissionDenied, message: "Geolocation denied.")))
            case .authorizedAlways, .authorizedWhenInUse:
                STACollectData.stopListeningAuthorizationChange()

                self?.getFingerprint(geolocation, completion)
            default:
                // `case .notDetermined` should never happen as the user must choose which permission to grant.
                // `CLAuthorizationStatus` may have additional unknown values, possibly added in future versions.
                break
            }
        }
    }

    func getFingerprint(_ geolocation: Bool,
                        _ completion: @escaping DeviceInformationResponse) {
        STACollectData.fingerprint(getLocation: geolocation) { result in
            switch result {
            case .success(let fingerprintSuccess):
                if case .failure(let error) = fingerprintSuccess.location {
                    // NOTE: the errors code .gpsError and .gpsDisabled are thrown here
                    completion(.failure(error.mapToNativeError()))
                    return
                }

                completion(.success(fingerprintSuccess.toDeviceInformationResult()))
            case .failure(let error):
                completion(.failure(error.mapToNativeError()))
            }
        }
    }
}
