import STAIdentify

class IdentifySdkPluginSelfieImpl: IdentifySdkPluginSelfie {
    func collect(parameters: CollectSelfieParameters?, completion: @escaping (Result<CollectSelfieResult, Error>) -> Void) {
        let validateLiveness = parameters?.validateLiveness ?? false
        let biometricValidation = mapFrom(biometricValidationCpf: parameters?.biometricValidationCpf)

        let selfieViewController = STACollectSelfie(validateLiveness: validateLiveness,
                                                biometricValidation: biometricValidation)
        selfieViewController.didCompleteSelfie { result in
            switch result {
            case .success(let selfieSuccess):
                completion(.success(selfieSuccess.toCollectSelfieResult()))
            case .failure(let error):
                completion(.failure(error.mapToNativeError()))
            }
        }

        DispatchQueue.main.async {
            if let rootVC = ViewControllerUtils.rootViewController {
                rootVC.present(selfieViewController, animated: true)
            }
        }
    }

    func mapFrom(biometricValidationCpf: String?) -> STABiometricValidationData? {
        guard let biometricValidationCpf = biometricValidationCpf else {
            return nil
        }

        if biometricValidationCpf.isEmpty {
            return nil
        }

        return STABiometricValidationData(cpf: biometricValidationCpf)
    }
}

