/// All possible errors that can occur during a Document Capture validation.
enum DocumentValidationErrorEnum {
  /// The image did not have enough quality to run the validation.
  imageNotGoodEnough,

  /// No document was detected in the image.
  documentNotDetected,

  /// No face in the document was detected in the image.
  noFaceDetected,

  /// There were more than one face in the image.
  tooManyFaces,

  /// The front of the document was detected when the back was requested.
  documentFrontDetected,

  /// The back of the document was detected when the front was requested.
  documentBackDetected,

  /// There was an error detecting the document.
  documentDetectionFailure,

  /// The document was detected but it was not possible to identify which side was.
  noDocumentSideDetected,

  /// Multiple documents were detected.
  multipleDocuments,

  /// The document detected was cropped.
  croppedDocument,

  /// The document detected is opened (both sides were detected at same time).
  openedDocument,

  /// The client's Identify account is configured to not allow the type of document detected.
  documentTypeNotAllowed,

  /// The detected face in the document was smiling.
  ///
  /// Note: this is an optional validation and needs to be activated in the
  /// account configuration.
  faceIsSmiling,

  /// An unknown error occurred during validation.
  unknownError,
}
