/// All possible errors that can occur during a LiveSelfie validation.
enum SelfieValidationErrorEnum {
  /// The image did not have enough quality to run the validation.
  imageNotGoodEnough,

  /// No face was detected in the image.
  noFaceDetected,

  /// There were more than one face in the image.
  tooManyFaces,

  /// The face did not have a neutral pose, i.e. the face was not looking
  /// towards the camera.
  tiltedFace,

  /// The detected face was wearing headwear.
  wearingHat,

  /// The detected face was wearing a mask.
  wearingGlasses,

  /// The detected face was wearing reading glasses.
  ///
  /// **Note**: this is an optional validation and needs to be activated in the
  /// account configuration.
  wearingReadingGlasses,

  /// The detected face was wearing a mask.
  wearingMask,

  /// The detected face was not centered in the image.
  faceNotCentered,

  /// The detected face was too far from the camera.
  faceTooFar,

  /// The detected face was smiling.
  ///
  /// **Note**: this is an optional validation and needs to be activated in the
  /// account configuration.
  faceIsSmiling,

  /// The detected face was too close to the camera.
  faceTooClose,

  /// The detected face's luminance was too high.
  faceTooBright,

  /// The detected face's luminance was too low.
  faceTooDark,

  /// The detected faces did not pass the facematch test.
  facesDoNotMatch,

  /// There was some inconsistency in biometric validation.
  biometricValidationError,

  /// There was some inconsistency in liveness validation.
  livenessNotOk,

  /// An unknown error occurred during validation.
  unknownError,
}
