import '../enums/all.dart';
import 'all.dart';

/// An error that can occur during a Document Capture validation.
///
/// This error may be thrown when calling [IdentifySdkFlutter.collectDocument].
class CollectDocumentException extends IdentifyException {
  /// All the errors that may occur during a document validation.
  final List<DocumentValidationErrorEnum>? validationErrors;

  /// @nodoc
  CollectDocumentException({required super.message, this.validationErrors})
      : super(code: IdentifyErrorCodeEnum.collectDocumentValidationError);

  @override
  Object encode() {
    return <Object?>[
      code.index,
      message,
      validationErrors,
    ];
  }

  /// @nodoc
  static CollectDocumentException decode(Object result) {
    result as List<Object?>;
    return CollectDocumentException(
        message: result[1]! as String,
        validationErrors: (result[2] as List<Object?>?)
            ?.map((e) => DocumentValidationErrorEnum.values[e! as int])
            .toList());
  }
}
