import '../enums/all.dart';
import '../models/all.dart';
import 'all.dart';

/// An error that can occur during a CollectSelfie validation.
class CollectSelfieException extends IdentifyException {
  /// All the errors that may occur during a selfie validation.
  final List<SelfieValidationErrorEnum>? validationErrors;

  /// All information about optional validations.
  final SelfieOptionalValidations? optionalValidations;

  /// @nodoc
  CollectSelfieException(
      {required super.message, this.validationErrors, this.optionalValidations})
      : super(code: IdentifyErrorCodeEnum.collectSelfieValidationError);

  @override
  Object encode() {
    return <Object?>[
      code.index,
      message,
      validationErrors,
      optionalValidations?.encode(),
    ];
  }

  /// @nodoc
  static CollectSelfieException decode(Object result) {
    result as List<Object?>;
    return CollectSelfieException(
        message: result[1]! as String,
        validationErrors: (result[2] as List<Object?>?)
            ?.map((e) => SelfieValidationErrorEnum.values[e! as int])
            .toList(),
        optionalValidations: result[3] != null
            ? SelfieOptionalValidations.decode(result[3]! as List<Object?>)
            : null);
  }
}
