import '../enums/all.dart';

/// Biometric success result.
class BiometricResult {
  /// @nodoc
  BiometricResult({
    required this.isAvailable,
    this.identityConfirmationProbability,
    this.serviceProviderAvailable,
    this.similarity,
  });

  /// Whether biometric result data is available.
  bool isAvailable;

  /// Status of the identity confirmation.
  BiometricValidationProbabilityEnum? identityConfirmationProbability;

  /// Whether biometric service provider is available.
  bool? serviceProviderAvailable;

  /// Similarity between the captured photo and the registered person.
  double? similarity;

  /// @nodoc
  Object encode() {
    return <Object?>[
      isAvailable,
      identityConfirmationProbability?.index,
      serviceProviderAvailable,
      similarity,
    ];
  }

  /// @nodoc
  static BiometricResult decode(Object result) {
    result as List<Object?>;
    return BiometricResult(
      isAvailable: result[0]! as bool,
      identityConfirmationProbability: result[1] != null
          ? BiometricValidationProbabilityEnum.values[result[1]! as int]
          : null,
      serviceProviderAvailable: result[2] as bool?,
      similarity: result[3] as double?,
    );
  }
}
