import '../enums/all.dart';
import 'all.dart';

/// All information about the document image captured during the document flow.
class CollectDocumentResult {
  /// @nodoc
  CollectDocumentResult({
    required this.documentType,
    required this.documentInfo,
    required this.image,
    required this.requestId,
    this.optionalValidations,
  });

  /// Document type.
  DocumentTypeEnum documentType;

  /// Document information.
  List<DocumentInfo> documentInfo;

  /// The image of the Document flow, encoded using base64.
  String image;

  /// An identifier representing the API calls that happened during capture flow.
  String requestId;

  /// All document optional validations requested.
  DocumentOptionalValidationsResult? optionalValidations;

  /// @nodoc
  Object encode() {
    return <Object?>[
      documentType.index,
      documentInfo,
      image,
      requestId,
      optionalValidations?.encode(),
    ];
  }

  /// @nodoc
  static CollectDocumentResult decode(Object result) {
    result as List<Object?>;
    return CollectDocumentResult(
      documentType: DocumentTypeEnum.values[result[0]! as int],
      documentInfo: (result[1] as List<Object?>?)!.cast<DocumentInfo>(),
      image: result[2]! as String,
      requestId: result[3]! as String,
      optionalValidations: result[4] != null
          ? DocumentOptionalValidationsResult.decode(
              result[4]! as List<Object?>)
          : null,
    );
  }
}
