import '../enums/all.dart';
import 'all.dart';

/// The result of a successful invocation of [collectOcr]. This object
/// contains the status of the request and the extracted information from the
/// document or the execution message.
class CollectOcrResult {
  /// @nodoc
  CollectOcrResult({
    required this.status,
    this.ocrInfo,
    this.msg,
  });

  /// The status of the [collectOcr] request.
  OcrStatusEnum status;

  /// OCR data for the back or front of a document.
  OcrInfo? ocrInfo;

  /// OCR execution message.
  String? msg;

  /// @nodoc
  Object encode() {
    return <Object?>[
      status.index,
      ocrInfo?.encode(),
      msg,
    ];
  }

  /// @nodoc
  static CollectOcrResult decode(Object result) {
    result as List<Object?>;
    return CollectOcrResult(
      status: OcrStatusEnum.values[result[0]! as int],
      ocrInfo: result[1] != null
          ? OcrInfo.decode(result[1]! as List<Object?>)
          : null,
      msg: result[2] as String?,
    );
  }
}
