import 'all.dart';

/// The result of a successful invocation of [collectSelfie]. This object
/// contains all information about the images captured during the CollectSelfie
/// flow.
class CollectSelfieResult {
  /// @nodoc
  CollectSelfieResult({
    required this.requestId,
    required this.selfie,
    this.optionalValidations,
  });

  ///Identifier representing the API calls that happened during the
  ///CollectSelfie flow.
  String requestId;

  /// All information about the selfie image captured during the CollectSelfie
  /// flow.
  SelfieInfo selfie;

  /// All information about optional validations.
  SelfieOptionalValidations? optionalValidations;

  /// @nodoc
  Object encode() {
    return <Object?>[
      requestId,
      selfie.encode(),
      optionalValidations?.encode(),
    ];
  }

  /// @nodoc
  static CollectSelfieResult decode(Object result) {
    result as List<Object?>;
    return CollectSelfieResult(
      requestId: result[0]! as String,
      selfie: SelfieInfo.decode(result[1]! as List<Object?>),
      optionalValidations: result[2] != null
          ? SelfieOptionalValidations.decode(result[2]! as List<Object?>)
          : null,
    );
  }
}
