import '../enums/all.dart';
import 'all.dart';

/// Document information.
class DocumentInfo {
  /// @nodoc
  DocumentInfo({
    required this.confidence,
    required this.cropping,
    required this.boundingBox,
    this.classification,
    this.documentSide,
    this.documentName,
  });

  /// Confidence of the document's classification.
  double confidence;

  /// Cropping information of the document.
  DocumentCropping cropping;

  /// Bounding box of the document in the image.
  BoundingBox boundingBox;

  /// Classification od the document.
  DocumentClassificationEnum? classification;

  /// Side of the document. Can be [DocumentSideEnum.documentFront] or [DocumentSideEnum.documentBack].
  DocumentSideEnum? documentSide;

  /// Description of the document. Example: Brazil - Driving License.
  String? documentName;

  /// @nodoc
  Object encode() {
    return <Object?>[
      confidence,
      cropping.encode(),
      boundingBox.encode(),
      classification?.index,
      documentSide?.index,
      documentName,
    ];
  }

  /// @nodoc
  static DocumentInfo decode(Object result) {
    result as List<Object?>;
    return DocumentInfo(
      confidence: result[0]! as double,
      cropping: DocumentCropping.decode(result[1]! as List<Object?>),
      boundingBox: BoundingBox.decode(result[2]! as List<Object?>),
      classification: result[3] != null
          ? DocumentClassificationEnum.values[result[3]! as int]
          : null,
      documentSide:
          result[4] != null ? DocumentSideEnum.values[result[4]! as int] : null,
      documentName: result[5] as String?,
    );
  }
}
