import 'dart:ui';

import '../extensions/all.dart';

/// Class the represents the theme thar will be used to select the color of UI
/// elements. All colors must have the format #RRGGBB or #AARRGGBB.
class IdentifyTheme {
  /// @nodoc
  IdentifyTheme({
    required this.primaryColor,
    required this.successColor,
    required this.neutralColor,
  });

  /// Helper method to instantiate a [IdentifyTheme] class.
  factory IdentifyTheme.fromColors(
      Color primaryColor, Color successColor, Color neutralColor) {
    return IdentifyTheme(
        primaryColor: primaryColor.toHex(),
        successColor: successColor.toHex(),
        neutralColor: neutralColor.toHex());
  }

  /// Color in hex used on main UI elements, acting as a custom source color for the application.
  String primaryColor;

  /// Color in hex used for visual _feedback_, indicating success.
  String successColor;

  /// Color in hex used to complement the main UI elements colors.
  String neutralColor;

  /// @nodoc
  Object encode() {
    return <Object?>[
      primaryColor,
      successColor,
      neutralColor,
    ];
  }

  /// @nodoc
  static IdentifyTheme decode(Object result) {
    result as List<Object?>;
    return IdentifyTheme(
      primaryColor: result[0]! as String,
      successColor: result[1]! as String,
      neutralColor: result[2]! as String,
    );
  }
}
