/// Device information available only on iOS devices.
class IosOnlyDeviceInformation {
  /// @nodoc
  IosOnlyDeviceInformation({
    required this.deviceName,
    this.regionCode,
    this.fullAccuracyPermission,
  });

  /// The name the user has given to their device.
  String deviceName;

  /// Region code of the device. For example: "BR".
  String? regionCode;

  /// Whether or not the geolocation data has full accuracy about the device
  /// location.
  ///
  /// If the geolocation was not requested, this property will be `null`.
  ///
  /// On iOS 14.0+ the user can allow access to the device location with a
  /// reduced accuracy. This field is `true` if the user has allowed full access
  /// to the device location and `false` otherwise. On iOS prior to 14.0 this
  /// field is always `true`.
  bool? fullAccuracyPermission;

  /// @nodoc
  Object encode() {
    return <Object?>[
      deviceName,
      regionCode,
      fullAccuracyPermission,
    ];
  }

  /// @nodoc
  static IosOnlyDeviceInformation decode(Object result) {
    result as List<Object?>;
    return IosOnlyDeviceInformation(
      deviceName: result[0]! as String,
      regionCode: result[1] as String?,
      fullAccuracyPermission: result[2] as bool?,
    );
  }
}
