/// The geolocation information from the device. This information is obtained
/// using the device's GPS module.
class LocationData {
  /// @nodoc
  LocationData({
    required this.longitude,
    required this.latitude,
    required this.timestamp,
    this.altitude,
    this.accuracy,
    this.speed,
    this.speedAccuracy,
    this.bearing,
    this.bearingAccuracy,
  });

  /// The  device's longitude.
  double longitude;

  /// The  device's latitude.
  double latitude;

  /// The time at which this geolocation was determined. Represents the Unix
  /// epoch time in milliseconds (i.e. the amount of milliseconds since the
  /// start of the Unix epoch 00:00:00 January 1, 1970 UTC).
  int timestamp;

  /// The  device's altitude. This property is optional.
  double? altitude;

  /// The  accuracy of the device's geolocation. This property is optional.
  double? accuracy;

  /// The device's speed (in meters per second). This property is optional.
  double? speed;

  /// The accuracy device's speed (in meters per second). This property is
  /// optional.
  double? speedAccuracy;

  /// The direction in which the device is traveling (in degrees). This
  /// property is optional.
  double? bearing;

  /// The accuracy of the device's bearing (in degrees).  This property is
  /// optional.
  double? bearingAccuracy;

  /// @nodoc
  Object encode() {
    return <Object?>[
      longitude,
      latitude,
      timestamp,
      altitude,
      accuracy,
      speed,
      speedAccuracy,
      bearing,
      bearingAccuracy,
    ];
  }

  /// @nodoc
  static LocationData decode(Object result) {
    result as List<Object?>;
    return LocationData(
      longitude: result[0]! as double,
      latitude: result[1]! as double,
      timestamp: result[2]! as int,
      altitude: result[3] as double?,
      accuracy: result[4] as double?,
      speed: result[5] as double?,
      speedAccuracy: result[6] as double?,
      bearing: result[7] as double?,
      bearingAccuracy: result[8] as double?,
    );
  }
}
