import '../enums/all.dart';

/// Data returned from a document OCR execution. All fields are optional. Which
/// field will have value depends on the document type and the data that the
/// OCR was able to extract.
class OcrInfo {
  /// @nodoc
  OcrInfo({
    this.expeditionDate,
    this.location,
    this.type,
    this.issuanceDate,
    this.placeOfBirth,
    this.documentOrigin,
    this.ownerSigns,
    this.firstFiliation,
    this.secondFiliation,
    this.registerNumber,
    this.generalRegisterNumber,
    this.dateOfBirth,
    this.drivingLicenseCategory,
    this.fullName,
    this.drivingLicenseFirstIssuanceDate,
    this.cpf,
    this.expirationDate,
    this.expeditionIssuer,
    this.expeditionIssuerState,
    this.socialName,
    this.gender,
    this.nationality,
    this.classification,
    this.residencePeriod,
    this.surname,
  });

  /// Date when the document was issued.
  String? expeditionDate;

  ///Location where the document was issued.
  String? location;

  /// Type of the document.
  DocumentTypeEnum? type;

  /// Date of issuance of the document.
  String? issuanceDate;

  /// Document owner's place of birth.
  String? placeOfBirth;

  /// The document that was referenced to create this document (e.g. a birth certificate).
  String? documentOrigin;

  /// Whether document owner is able to sign.
  bool? ownerSigns;

  /// First filiation name.
  String? firstFiliation;

  /// Second filiation name.
  String? secondFiliation;

  /// Registration number extracted from the document.
  String? registerNumber;

  /// RG number extracted from the document.
  String? generalRegisterNumber;

  /// Document’s owner date of birth.
  String? dateOfBirth;

  /// Driving license category.
  String? drivingLicenseCategory;

  /// Name of the document's owner.
  String? fullName;

  /// Date of first issuance of the driving license.
  String? drivingLicenseFirstIssuanceDate;

  /// CPF (Brazilian national identification number).
  String? cpf;

  /// Document expiration date.
  String? expirationDate;

  /// Document issuer.
  String? expeditionIssuer;

  /// State where the document was issued.
  String? expeditionIssuerState;

  /// Document's owner social name.
  String? socialName;

  /// Document's owner gender.
  String? gender;

  /// Document's owner nationality.
  String? nationality;

  /// Value present only present in [DocumentTypeEnum.rne]. Indicates the
  /// document classification, like 'Resident' or 'Provisory'.
  String? classification;

  /// Value present only in [DocumentTypeEnum.rne]. Indicates until when the
  /// document's owner can stay in Brazil.
  String? residencePeriod;

  /// Surname of the document's owner.
  String? surname;

  /// @nodoc
  Object encode() {
    return <Object?>[
      expeditionDate,
      location,
      type?.index,
      issuanceDate,
      placeOfBirth,
      documentOrigin,
      ownerSigns,
      firstFiliation,
      secondFiliation,
      registerNumber,
      generalRegisterNumber,
      dateOfBirth,
      drivingLicenseCategory,
      fullName,
      drivingLicenseFirstIssuanceDate,
      cpf,
      expirationDate,
      expeditionIssuer,
      expeditionIssuerState,
      socialName,
      gender,
      nationality,
      classification,
      residencePeriod,
      surname,
    ];
  }

  /// @nodoc
  static OcrInfo decode(Object result) {
    result as List<Object?>;
    return OcrInfo(
      expeditionDate: result[0] as String?,
      location: result[1] as String?,
      type:
          result[2] != null ? DocumentTypeEnum.values[result[2]! as int] : null,
      issuanceDate: result[3] as String?,
      placeOfBirth: result[4] as String?,
      documentOrigin: result[5] as String?,
      ownerSigns: result[6] as bool?,
      firstFiliation: result[7] as String?,
      secondFiliation: result[8] as String?,
      registerNumber: result[9] as String?,
      generalRegisterNumber: result[10] as String?,
      dateOfBirth: result[11] as String?,
      drivingLicenseCategory: result[12] as String?,
      fullName: result[13] as String?,
      drivingLicenseFirstIssuanceDate: result[14] as String?,
      cpf: result[15] as String?,
      expirationDate: result[16] as String?,
      expeditionIssuer: result[17] as String?,
      expeditionIssuerState: result[18] as String?,
      socialName: result[19] as String?,
      gender: result[20] as String?,
      nationality: result[21] as String?,
      classification: result[22] as String?,
      residencePeriod: result[23] as String?,
      surname: result[24] as String?,
    );
  }
}
