import 'all.dart';

/// All information about the selfie image captured during the CollectSelfie
/// flow.
class SelfieInfo {
  /// @nodoc
  SelfieInfo({
    required this.image,
    required this.ageRange,
    required this.brightness,
    required this.confidence,
    required this.sharpness,
  });

  /// The first image of the LiveSelfie or CollectSelfie flow. Encoded using
  /// base64. The user is looking towards the camera and their photo is
  /// validated using the [ICAO](https://www.icao.int/Pages/default.aspx)
  /// standard.
  String image;

  /// The age range of the face detected on the selfie image.
  AgeRange ageRange;

  /// The brightness of the face detected on the selfie image.
  double brightness;

  /// The confidence that the selfie image contains a face. Range between 0 and
  /// 1.
  double confidence;

  /// The sharpness of the face detected on the selfie image.
  double sharpness;

  /// @nodoc
  Object encode() {
    return <Object?>[
      image,
      ageRange.encode(),
      brightness,
      confidence,
      sharpness,
    ];
  }

  /// @nodoc
  static SelfieInfo decode(Object result) {
    result as List<Object?>;
    return SelfieInfo(
      image: result[0]! as String,
      ageRange: AgeRange.decode(result[1]! as List<Object?>),
      brightness: result[2]! as double,
      confidence: result[3]! as double,
      sharpness: result[4]! as double,
    );
  }
}
