// ignore_for_file: public_member_api_docs

import 'package:flutter/services.dart';
import 'package:identify_sdk_flutter/src/codecs/identify_sdk_plugin_core_codec.dart';

import '../exceptions/connection_exception.dart';
import '../models/identify_theme.dart';

class IdentifySdkPluginCore {
  /// Constructor for [IdentifySdkPluginCore].  The [binaryMessenger] named argument is
  /// available for dependency injection.  If it is left null, the default
  /// BinaryMessenger will be used which routes to the host platform.
  IdentifySdkPluginCore({BinaryMessenger? binaryMessenger})
      : pigeonBinaryMessenger = binaryMessenger;
  final BinaryMessenger? pigeonBinaryMessenger;

  static const MessageCodec<Object?> pigeonChannelCodec =
      IdentifySdkPluginCoreCodec();

  Future<void> initializeSession(
      String token, String stage, IdentifyTheme? theme) async {
    const String pigeonChannelName =
        'dev.flutter.pigeon.identify_sdk_flutter.IdentifySdkPluginCore.initializeSession';
    final BasicMessageChannel<Object?> pigeonChannel =
        BasicMessageChannel<Object?>(
      pigeonChannelName,
      pigeonChannelCodec,
      binaryMessenger: pigeonBinaryMessenger,
    );
    final List<Object?>? pigeonReplyList = await pigeonChannel
        .send(<Object?>[token, stage, theme]) as List<Object?>?;
    if (pigeonReplyList == null) {
      throw ConnectionException(pigeonChannelName);
    } else if (pigeonReplyList.length > 1) {
      throw PlatformException(
        code: pigeonReplyList[0]! as String,
        message: pigeonReplyList[1] as String?,
        details: pigeonReplyList[2],
      );
    } else {
      return;
    }
  }
}
