// ignore_for_file: public_member_api_docs

import 'package:flutter/services.dart';

import '../codecs/all.dart';
import '../enums/all.dart';
import '../exceptions/all.dart';
import '../models/all.dart';

class IdentifySdkPluginDocument {
  /// Constructor for [IdentifySdkPluginDocument].  The [binaryMessenger] named argument is
  /// available for dependency injection.  If it is left null, the default
  /// BinaryMessenger will be used which routes to the host platform.
  IdentifySdkPluginDocument({BinaryMessenger? binaryMessenger})
      : pigeonBinaryMessenger = binaryMessenger;
  final BinaryMessenger? pigeonBinaryMessenger;

  static const MessageCodec<Object?> pigeonChannelCodec =
      IdentifySdkPluginDocumentCodec();

  Future<CollectDocumentResult> collect(
    DocumentSideEnum documentSide, [
    DocumentCaptureModeEnum? captureMode = DocumentCaptureModeEnum.manual,
    DocumentOptionalValidations? optionalValidations,
  ]) async {
    const String pigeonChannelName =
        'dev.flutter.pigeon.identify_sdk_flutter.IdentifySdkPluginDocument.collect';
    final BasicMessageChannel<Object?> pigeonChannel =
        BasicMessageChannel<Object?>(
      pigeonChannelName,
      pigeonChannelCodec,
      binaryMessenger: pigeonBinaryMessenger,
    );
    final List<Object?>? pigeonReplyList = await pigeonChannel.send(<Object?>[
      documentSide.index,
      captureMode?.index,
      optionalValidations
    ]) as List<Object?>?;
    if (pigeonReplyList == null) {
      throw ConnectionException(pigeonChannelName);
    } else if (pigeonReplyList.length > 1) {
      throw PlatformException(
        code: pigeonReplyList[0]! as String,
        message: pigeonReplyList[1] as String?,
        details: pigeonReplyList[2],
      );
    } else if (pigeonReplyList[0] == null) {
      throw PlatformException(
        code: 'null-error',
        message: 'Host platform returned null value for non-null return value.',
      );
    } else {
      return (pigeonReplyList[0] as CollectDocumentResult?)!;
    }
  }
}
